function [z] = mult3(x,y)
% [z] = mult3(x,y)
%
% Given two 3-dimensional arrays, multiply each pair of matrices 
% in the 'stacks' together.  That is: z(:,:,i) = x(:,:,i)*y(:,:,i);
% The C version is faster.

% Author: David Ross, Oct. 2005
% $Id: mult3.m,v 1.3 2006/01/13 19:22:31 dross Exp $

%-----------------------------------------------------------
% Check the input
%-----------------------------------------------------------

error(nargchk(2,2,nargin));

if ndims(x) > 3 | ndims(y) > 3
    error('x and y must both be 3-dimensional arrays');
end

K = size(x,3);

if size(x,2) ~= size(y,1)
    error('size(x,2) and size(y,1) must match for matrix multiplication');
end

if size(y,3) ~= K
    error('sizes of third dimensions of x and y must match');
end




%-----------------------------------------------------------
% Do it.
%-----------------------------------------------------------

z = zeros(size(x,1),size(y,2),K);
for kk = 1:K
    z(:,:,kk) = x(:,:,kk)*y(:,:,kk);
end
